@@ -32,7 +32,7 @@ from .schema import load_and_validate
 from . import util
 
 
-__version__ = '1.0.2'
+__version__ = '1.2.1'
 
 
 @contextmanager
@@ -1067,8 +1067,9 @@ class Case:
 
             util.log.debug(f"Using SRC='{self.sourcepath}', WRK='{workpath}', LOG='{logdir}'")
 
+            ignore_missing = self._ignore_missing
             for filemap in self._pre_files:
-                filemap.copy(namespace, self.sourcepath, workpath, sourcename='SRC', targetname='WRK')
+                filemap.copy(namespace, self.sourcepath, workpath, sourcename='SRC', targetname='WRK', ignore_missing=ignore_missing)
 
             success = True
             for command in self._commands:
